@@ -1,7 +1,7 @@
 from bs4 import BeautifulSoup
 from pptx import Presentation
 from pptx.presentation import Presentation as PresentationClass
-from newsworthy_slides.parsers import add_slide
+from newsworthy_slides.parsers import add_slide, add_metadata
 
 def slides_from_xml(slides_xml, base_presentation):
     """Adds slides to a presentation by parsing our custom xml/html markup
@@ -16,6 +16,8 @@ def slides_from_xml(slides_xml, base_presentation):
     else:
         pres = Presentation(base_presentation)
 
+    add_metadata(slides_xml, pres)
+
     slides_soup = BeautifulSoup(slides_xml, 'html.parser').select("slide")
 
     for i, slide_soup in enumerate(slides_soup):
