@@ -10,7 +10,7 @@ from pptx.enum.text import PP_ALIGN
 from pptx.enum.shapes import PP_PLACEHOLDER 
 from pptx.enum.text import MSO_AUTO_SIZE
 from pptx import Presentation
-from pptx.slide import Slide
+from pptx.slide import Slide, NotesSlide
 
 from newsworthy_slides.utils import (move_slide, inner_html, get_placeholder,
                                      get_slide_layout)
@@ -95,6 +95,11 @@ def add_slide(slide_xml, pres):
             raise SlidePositionInvalid(msg)
         move_slide(pres, -1, position)
 
+    # Parse notes
+    notes_soup = slide_soup.select_one("notes")
+    if notes_soup:
+        notes_obj = _parse_notes(notes_soup, slide_obj)
+
     return slide_obj
 
 def add_metadata(presentation_xml, presentation):
@@ -187,7 +192,10 @@ def _parse_text_placeholder(placeholder_soup, slide_shape):
     https://python-pptx.readthedocs.io/en/latest/user/text.html
     """
     ## Set slide text frame
-    text_frame = slide_shape.text_frame
+    if isinstance(slide_shape, NotesSlide):
+        text_frame = slide_shape.notes_text_frame
+    else:
+        text_frame = slide_shape.text_frame
     auto_size = False
 
     if placeholder_soup.name == "placeholder":
@@ -374,6 +382,18 @@ def _parse_table_placeholder(placeholder_soup, placeholder_obj):
 
     return placeholder_obj
 
+def _parse_notes(notes_soup, slide_obj):
+    """Adds notes based on content from a <note> tag.
+    """
+    notes_slide = slide_obj.notes_slide
+    # Notes are really slides with similar features as regular slides.
+    # Hence we can use the same parser as we do for regular slide placeholder.
+    # However, for now we don't support images, tables etc in notes. Instead we assume
+    # the notes to only contain text.
+    # Hackishly we place it in a <placeholder> tag to be able to re-use  _parse_text_placeholder()
+    notes_soup = BeautifulSoup(f'<placeholder type="text">{notes_soup}</placeholder>', 'html.parser')
+    _parse_text_placeholder(notes_soup, notes_slide)
+    return notes_slide
 
 
 ###
