@@ -111,6 +111,21 @@ def test_add_slide_without_layout():
     with pytest.raises(SlideLayoutInvalid):
         add_slide(html, test_pres)
 
+def test_add_slide_with_notes():
+    # Add placeholders with explicit names
+    html = """
+    <slide layout="Avsnittsrubrik">
+        <placeholder type="text" name="Title 1">My title</placeholder>
+        <notes>
+            <li>An important note to keep in mind<li>
+        </notes>
+    <slide>
+    """
+    slide = add_slide(html, test_pres)
+    assert(slide.has_notes_slide)
+    notes_slide = slide.notes_slide
+    assert(notes_slide.notes_text_frame.text.strip()=="An important note to keep in mind")
+
 def test_parse_text_with_no_tags():
     html = """
         <placeholder type="text">Hello world</placeholder>
