@@ -21,6 +21,10 @@ def test_basic():
     <placeholder type="image" vertical-alignment="bottom">
         <img src="test/data/robot-writer-chart.png">
     </placeholder>
+
+    <notes>
+        <li>Read more <a href="https://www.newsworthy.se">on our site</a></li>
+    </notes>
 </slide>
 <slide layout="Två innehållsdelar">
     <placeholder type="text">Mycket text här</placeholder>
